##  2. What is a cookie?
Cookies are small temporary files stored in your browsing device (computer, telephone, tablet, etc) when you visit a website. Cookies enable the website to store certain information in your device, for example to store user preferences or to recognize you if you visit the website later.
When a cookie is created in your device, the following information is stored:
  * The address (domain) of the website that created the cookie.
  * The duration of the cookie.
  * The content of the cookie.


You can configure your web browser at any time to block the use of cookies by certain websites. You may delete previously stored cookies as well.
